==> jc-1.4.0.tar.gz: javax/swing/AbstractButton__244.h <==
// final class javax.swing.AbstractButton$4

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 37722e01fe2479c8 javax_swing_AbstractButton__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_AbstractButton__244_H_
#define _JC_javax_swing_AbstractButton__244_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_AbstractButton$object;

// Typedefs
typedef struct _jc_javax_swing_AbstractButton__244$sub_refs	_jc_javax_swing_AbstractButton__244$sub_refs;
typedef struct _jc_javax_swing_AbstractButton__244$sub_nonrefs	_jc_javax_swing_AbstractButton__244$sub_nonrefs;
typedef struct _jc_javax_swing_AbstractButton__244$refs	_jc_javax_swing_AbstractButton__244$refs;
typedef struct _jc_javax_swing_AbstractButton__244$nonrefs	_jc_javax_swing_AbstractButton__244$nonrefs;
typedef struct _jc_javax_swing_AbstractButton__244$object	_jc_javax_swing_AbstractButton__244$object;

typedef const struct _jc_javax_swing_AbstractButton__244$vmethods	_jc_javax_swing_AbstractButton__244$vmethods;
typedef const struct _jc_javax_swing_AbstractButton__244$vtable	_jc_javax_swing_AbstractButton__244$vtable;
typedef const struct _jc_javax_swing_AbstractButton__244$vtype	_jc_javax_swing_AbstractButton__244$vtype;

// Constructors
extern void _jc_javax_swing_AbstractButton__244$method$_init$5ba87353af70f491(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_javax_swing_AbstractButton$object *);

// Virtual methods
extern void _jc_javax_swing_AbstractButton__244$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_java_awt_event_ItemEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_AbstractButton__244$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_AbstractButton__244$vmethods {
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_java_awt_event_ItemEvent$object *);
};

// Vtable
struct _jc_javax_swing_AbstractButton__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractButton__244$vmethods	javax_swing_AbstractButton__244;
};

// Vtype
struct _jc_javax_swing_AbstractButton__244$vtype {
	_jc_type			type;
	_jc_javax_swing_AbstractButton__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_AbstractButton__244$sub_refs {
	struct _jc_javax_swing_AbstractButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_AbstractButton__244$refs {
    _jc_javax_swing_AbstractButton__244$sub_refs	javax_swing_AbstractButton__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_AbstractButton__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_AbstractButton__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractButton__244$sub_nonrefs	javax_swing_AbstractButton__244;
};

// Object instance structure
struct _jc_javax_swing_AbstractButton__244$object {
	_jc_javax_swing_AbstractButton__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_AbstractButton__244$vtype	*vtype;
	_jc_javax_swing_AbstractButton__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_AbstractButton__244$vtype _jc_javax_swing_AbstractButton__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_AbstractButton__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_AbstractButton__244$class_object;

#endif	/* _JC_javax_swing_AbstractButton__244_H_ */

==> jc-1.4.5.tar.gz: javax/swing/AbstractButton__244.h <==
// final class javax.swing.AbstractButton$4

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 37722e01fe2479c8 javax_swing_AbstractButton__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_AbstractButton__244_H_
#define _JC_javax_swing_AbstractButton__244_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_AbstractButton$object;

// Typedefs
typedef struct _jc_javax_swing_AbstractButton__244$sub_refs	_jc_javax_swing_AbstractButton__244$sub_refs;
typedef struct _jc_javax_swing_AbstractButton__244$sub_nonrefs	_jc_javax_swing_AbstractButton__244$sub_nonrefs;
typedef struct _jc_javax_swing_AbstractButton__244$refs	_jc_javax_swing_AbstractButton__244$refs;
typedef struct _jc_javax_swing_AbstractButton__244$nonrefs	_jc_javax_swing_AbstractButton__244$nonrefs;
typedef struct _jc_javax_swing_AbstractButton__244$object	_jc_javax_swing_AbstractButton__244$object;

typedef const struct _jc_javax_swing_AbstractButton__244$vmethods	_jc_javax_swing_AbstractButton__244$vmethods;
typedef const struct _jc_javax_swing_AbstractButton__244$vtable	_jc_javax_swing_AbstractButton__244$vtable;
typedef const struct _jc_javax_swing_AbstractButton__244$vtype	_jc_javax_swing_AbstractButton__244$vtype;

// Constructors
extern void _jc_javax_swing_AbstractButton__244$method$_init$5ba87353af70f491(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_javax_swing_AbstractButton$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_AbstractButton__244$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_AbstractButton__244$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_AbstractButton__244$vmethods {
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_AbstractButton__244$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_AbstractButton__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractButton__244$vmethods	javax_swing_AbstractButton__244;
};

// Vtype
struct _jc_javax_swing_AbstractButton__244$vtype {
	_jc_type			type;
	_jc_javax_swing_AbstractButton__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_AbstractButton__244$sub_refs {
	struct _jc_javax_swing_AbstractButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_AbstractButton__244$refs {
    _jc_javax_swing_AbstractButton__244$sub_refs	javax_swing_AbstractButton__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_AbstractButton__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_AbstractButton__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractButton__244$sub_nonrefs	javax_swing_AbstractButton__244;
};

// Object instance structure
struct _jc_javax_swing_AbstractButton__244$object {
	_jc_javax_swing_AbstractButton__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_AbstractButton__244$vtype	*vtype;
	_jc_javax_swing_AbstractButton__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_AbstractButton__244$vtype _jc_javax_swing_AbstractButton__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_AbstractButton__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_AbstractButton__244$class_object;

#endif	/* _JC_javax_swing_AbstractButton__244_H_ */
